@@ -1,6 +1,5 @@
 from .create_sql_query import CreateSqlQueryPayload
 from .sql_query import SqlQueryPayload
-from .sql_query_metadata import SqlQueryMetadataPayload
 from .sql_result_pagination import SqlResultPaginationPayload
 from .delete_statement import DeleteStatementPayload
 
@@ -8,7 +7,6 @@ from .delete_statement import DeleteStatementPayload
 __all__ = [
     "CreateSqlQueryPayload",
     "SqlQueryPayload",
-    "SqlQueryMetadataPayload",
     "SqlResultPaginationPayload",
     "DeleteStatementPayload",
 ]
