@@ -71,7 +71,7 @@ def test_binary(client):
 
 
 def test_csv(client):
-    with open(NORMAL_CSV) as file:
+    with open(NORMAL_CSV, encoding='utf-8') as file:
         spamreader = csv.reader(file)
         uploaded_csv = []
         for row in spamreader:
